@@ -1,12 +1,14 @@
 import logging
 
-from skippy.data.minio import upload_file, download_files
+from skippy.data.minio import upload_files, download_files
 
 
 def consume(urns=None):
     def wrapper(func):
         level = logging.DEBUG
-
+        logging.basicConfig(format='%(asctime)s|%(levelname)-s|%(message)s',
+                            level=logging.DEBUG,
+                            datefmt='%d.%m.%Y %H:%M:%S')
         # Set the log level
         logging.getLogger().setLevel(level)
         logging.info('Consume.wrapper(%s)' % func)
@@ -26,7 +28,9 @@ def consume(urns=None):
 def produce(urn=None):
     def wrapper(func):
         level = logging.DEBUG
-
+        logging.basicConfig(format='%(asctime)s|%(levelname)-s|%(message)s',
+                            level=logging.DEBUG,
+                            datefmt='%d.%m.%Y %H:%M:%S')
         # Set the log level
         logging.getLogger().setLevel(level)
         logging.info('Produce.wrapper(%s)' % func)
@@ -35,7 +39,7 @@ def produce(urn=None):
 #            logging.info('Produce.call (%s,%s,%s)' % (func, args, kwargs))
             logging.info('Produce.call')
             response = func(*args, **kwargs)
-            upload_file(response, urn)
+            upload_files(response, urn)
 #            logging.debug('Produce.store(%s)' % response)
             return response
 
